@@ -9,13 +9,13 @@ using namespace std;
 int main(int argc, char **argv)
 try
 {
-    if (argc == 1)
+    if (argc == 1)              // initiator: create DH parameters
     {
         DiffieHellman dh(1024, 5, true);
         dh.save("init", DiffieHellman::SAVE_SECRET_KEY);
     }
 
-    if (argc == 2)
+    if (argc == 2)              // peer: save peer's scret key
     {
         DiffieHellman dh("init.pub");
         dh.save("peer", DiffieHellman::SAVE_SECRET_KEY);
