@@ -2,6 +2,6 @@
 
 void Log::init()
 {
-    d_level = 0;
     d_activeLevel = numeric_limits<size_t>::max();
+    setLevel(0);
 }
