@@ -3,7 +3,7 @@
 Pipe::Pipe()
 {
     if (pipe(d_fd))
-        throw Exception() << "Pipe::Pipe(): " << errnodescr;
+        throw Exception{} << "Pipe::Pipe(): " << errnodescr;
 }
 
 
